# initialisation

proc zero_conf {} {
    global mycompta

    set mycompta(dbname) ""
    set mycompta(host) ""
    set mycompta(port) ""
    set mycompta(user) ""
    set mycompta(password) ""
    set mycompta(authtype) ""
    set mycompta(conf) ""
    set mycompta(lib) ""
    set mycompta(sauv) ""
    set mycompta(version_conf) ""
    if [catch {array names "version_base"}] {set mycompta(version_base) ""}
    if [catch {array names "version"}] {set mycompta(version) ""}
}

proc initialise_conf {} {
    global mycompta

    set opt [open $mycompta(conf) r]
    while {! [eof $opt]} {
        set l [gets $opt]
        if {$l != "" && $l != -1 && [string index [lindex $l 0] 0] != "\#"} {
            set val [lindex $l 1]
            if {$val == "default"} {set val ""}
            set mycompta([lindex $l 0]) $val
        }
    }
    close $opt
}

# connexion  la base de donnes
proc connect {arg} {
    global mycompta

    set conn ""
    if {$arg != ""} {set mycompta(dbname) $arg}
    set comm_connect ""
    foreach indice {dbname port host user password authtype} {
        if {$mycompta($indice) != ""} {append comm_connect " $indice=$mycompta($indice)"}
    }
    # charger la librairie de postgres
    load /usr/lib/libpgtcl.so pgtcl

    # puts [ pg_conndefaults]
    set conn [pg_connect -conninfo "$comm_connect"]

    # faire vrif des versions quand changement, et upgrade dans la base

    # format date: dd-mm-aaaa
    catch {pg_exec $conn "SET DATESTYLE to 'European';"}
    
    return $conn
}

# poser lock logiciel
# arg: mode: 0 si texte, 1 si graphique
proc pose_lock {{mode 0}} {
    global conn errorInfo

    set res ""
    if [catch {set res [pg_exec $conn "SELECT valeur FROM Divers WHERE variable = 'lock_logiciel';"]}] {
	if {$res != ""} {pg_result $res -clear}
        set mess "En vrifiant le lock logiciel, erreur Postgres: $errorInfo"
	if {$mode} {
            tk_dialog .mess_tcl "BUG" $mess error 0 OK
        } else {
            puts $mess
        }
        exit 1
    } else {
        pg_result $res -assign l
        pg_result $res -clear
        if {$l(0,valeur) != "0"} {
            if {$mode} {
                set but 0
                set but [tk_dialog .mess_tcl "Impossible" "Ce logiciel est dj lanc et ne doit pas tre lanc plusieurs fois. Si vous pensez que ce message est une erreur, vous pouvez outrepasser cet avertissement." error 0 "OK" "Outrepasser"]
                if {$but == 0} {exit 1}
            } else {
                puts "Ce logiciel est dj lanc et ne doit pas tre lanc plusieurs fois."
                exit 1
            }
        } else {
            if [catch {pg_exec $conn "UPDATE Divers SET valeur = '1' WHERE variable = 'lock_logiciel';"}] {
                set mess "En posant le lock logiciel, erreur Postgres: $errorInfo"
                if {$mode} {
                    tk_dialog .mess_tcl "BUG" $mess error 0 OK
                } else {
                    puts $mess
                }
                exit 1
            }
        }
    }
}

# lire conf
#  faire: vrif de la version des fichiers de conf et concordance entre eux
proc lire_conf {} {
    global mycompta env

    # mise  blanc de mycompta avant de lire les fichiers de conf
    zero_conf

    set mycompta(conf) "/etc/mycompta.conf"
    # lire configuration gnrale
    catch {set mycompta(conf) $env(MYCOMPTA_CONF)}
    if {! [file exists $mycompta(conf)]} {
        puts "Pas de fichier de conf, $mycompta(conf), revoyez votre installation ou la var d'environnement MYCOMPTA_CONF"
        exit 1
    }
    initialise_conf

    # lire configuration particulire
    if [file exists "~/.mycompta.conf"] {
        set mycompta(conf) "~/.mycompta.conf"
        initialise_conf
    }
}
